@@ -593,7 +593,7 @@ def cal_performance(para_combination):
         signal_year_mean = np.mean(signal_year_count)
         cov = round(signal_year_std / signal_year_mean, 3)
 
-        result_dict['cov'] = cov
+        result_dict['cov_count'] = cov
 
         # Win rate by year
         for year in year_list:
@@ -609,6 +609,7 @@ def cal_performance(para_combination):
         # Performance by year
         first_equity_value = 0
         last_equity_value = 0
+        year_return_list = []
         for year in year_list:
             if not df.loc[df['year'] == year].empty:  # if trade
                 if first_equity_value == 0:  # if 1st year, set beginning as the first equity_value
@@ -617,14 +618,23 @@ def cal_performance(para_combination):
                 yearly_return = (last_equity_value - first_equity_value) / first_equity_value
                 if np.isnan(yearly_return):
                     result_dict[f'{year}_return'] = 0
+                    year_return_list.append(0)
                 else:
                     result_dict[f'{year}_return'] = int(yearly_return * 100)
+                    year_return_list.append(int(yearly_return * 100))
 
             else:  # no trade
                 result_dict[f'{year}_return'] = '-----'
+                year_return_list.append(0)
 
             first_equity_value = last_equity_value
 
+        # cov_return
+        return_year_std = np.std(year_return_list)
+        return_year_mean = np.mean(year_return_list)
+        cov_return = round(return_year_std / return_year_mean, 3)
+        result_dict['cov_return'] = cov_return
+
     result_dict['risk_free_rate'] = risk_free_rate
 
     # BaH Performance
