@@ -38,8 +38,10 @@ class Components:
                                                        {'label': 'MDD Percentage <', 'value': 'mdd_pct<'},
                                                        {'label': 'Trade Count >', 'value': 'num_of_trade>'},
                                                        {'label': 'Trade Count <', 'value': 'num_of_trade<'},
-                                                       {'label': 'COV >', 'value': 'cov>'},
-                                                       {'label': 'COV <', 'value': 'cov<'},
+                                                       {'label': 'COV (Count) >', 'value': 'cov_count>'},
+                                                       {'label': 'COV (Count) <', 'value': 'cov_count<'},
+                                                       {'label': 'COV (Return) >', 'value': 'cov_return>'},
+                                                       {'label': 'COV (Return) <', 'value': 'cov_return<'},
                                                        {'label': 'Win Rate >', 'value': 'win_rate>'},
                                                        {'label': 'Win Rate <', 'value': 'win_rate<'},
                                                    ],
@@ -226,7 +228,8 @@ class Components:
                 'net_profit_to_mdd',
                 'return_to_bah',
                 'win_rate',
-                'cov',
+                'cov_count',
+                'cov_return',
                 'total_commission',
                 'return_on_capital',
                 'annualized_return',
@@ -254,7 +257,8 @@ class Components:
             df['annualized_return'] = "{:.0%}".format(df['annualized_return'] / 100)
             df['annualized_std'] = "{:.0%}".format(df['annualized_std'] / 100)
 
-            df['cov'] = round(df['cov'], 2)
+            df['cov_count'] = round(df['cov_count'], 2)
+            df['cov_return'] = round(df['cov_return'], 2)
 
             try:
                 df['win_rate'] = "{:.0%}".format( float(df['win_rate']) / 100)
@@ -280,7 +284,8 @@ class Components:
         per_col_1_1.append(html.Div('Net Profit/MDD'))
         per_col_1_1.append(html.Div('Return-BaH % Diff.'))
         per_col_1_1.append(html.Div('Win Rate'))
-        per_col_1_1.append(html.Div('COV'))
+        per_col_1_1.append(html.Div('COV (Count)'))
+        per_col_1_1.append(html.Div('COV (Return)'))
         per_col_1_1.append(html.Div('Total Commission'))
         per_col_1_1.append(html.Div('Risk Free Rate'))
 
@@ -401,7 +406,8 @@ class Components:
         'annualized_return': 'Annualized Return',
         'annualized_sr': 'Sharp Ratio',
         'mdd_pct':'MDD Percentage',
-        'cov':'COV',
+        'cov_count':'COV (Count)',
+        'cov_return': 'COV (Return)',
         'win_rate':'Win Rate',
         'return_to_bah': 'Return/BnH % Diff.',
         'exclude': 'Exclude',
@@ -592,7 +598,8 @@ class Components:
             hovertemplate = hovertemplate + "MDD Percentage : " + "{:.0%}".format(
                 graph_df.iloc[i]['mdd_pct'] / 100) + "<br>"
             hovertemplate = hovertemplate + "Trade Count : " + str(graph_df.iloc[i]['num_of_trade']) + "<br>"
-            hovertemplate = hovertemplate + "COV : " + str(round(graph_df.iloc[i]['cov'], 2)) + "<br>"
+            hovertemplate = hovertemplate + "COV (Count) : " + str(round(graph_df.iloc[i]['cov_count'], 2)) + "<br>"
+            hovertemplate = hovertemplate + "COV (Return) : " + str(round(graph_df.iloc[i]['cov_return'], 2)) + "<br>"
             try:
                 hovertemplate = hovertemplate + "Win Rate : " + "{:.0%}".format(
                     float(graph_df.iloc[i]['win_rate']) / 100) + "<br>"
@@ -1048,6 +1055,7 @@ class Components:
 
                 dict = {}
                 # parameters = ast.literal_eval(row['para_combination'])
+
                 dict['para_combination'] = ast.literal_eval(row['para_combination'])
                 para_combination = ast.literal_eval(row['para_combination'])
                 dict['para_combination'] = para_combination
@@ -1140,7 +1148,7 @@ class Components:
                     performance_text.append(html.Div(f'{item} : {_value}', style={'line-height': line_height}))
 
                 if key == 'return_on_capital':
-                    item = 'Return on Capital'
+                    item = 'ReturnOnCapital'
                     _value = "{:.0%}".format(value/100)
                     performance_text.append(html.Div(f'{item} : {_value}', style={'line-height': line_height}))
 
@@ -1303,6 +1311,7 @@ class Components:
         year_win_rate_col = []
         year_return_col = []
 
+        year_return_list = []
         for year in year_list:
             year_col.append(html.Div(year))
             year_count.append(int(total_dict[f'{year}']))
@@ -1312,7 +1321,13 @@ class Components:
             year_return = total_dict[f'{year}_return']
             year_return_col.append(html.Div( "{:.0%}".format(year_return) ))
 
-        cov = round(np.std(year_count) / np.mean(year_count), 2)
+            try:
+                year_return_list.append(float(year_return))
+            except:
+                year_return_list.append(0)
+
+        cov_count = round(np.std(year_count) / np.mean(year_count), 2)
+        cov_return = round(np.std(year_return_list) / np.mean(year_return_list), 2)
 
         div = html.Div([
 
@@ -1325,7 +1340,8 @@ class Components:
                          html.Div('Net Profit'),
                          html.Div('Net Profit/MDD'),
                          html.Div('Win Rate'),
-                         html.Div('COV'),
+                         html.Div('COV (Count)'),
+                         html.Div('COV (Return)'),
                          html.Div('Total Commission'),
                          html.Div('Risk Free Rate'),
                          html.Div(style={'height': '10px'}),
@@ -1342,7 +1358,8 @@ class Components:
                          html.Div(net_profit),
                          html.Div(net_profit_to_mdd),
                          html.Div(win_rate),
-                         html.Div(cov),
+                         html.Div(cov_count),
+                         html.Div(cov_return),
                          html.Div(total_commission),
                          html.Div("{:.2%}".format(risk_free_rate_float / 100)),
                          html.Div(style={'height': '10px'}),
